@@ -31,15 +31,17 @@ import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitor;
 import org.gcube.portlets.user.td.gwtservice.shared.monitor.OperationMonitorSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXImportSession;
+import org.gcube.portlets.user.td.gwtservice.shared.sdmx.SDMXTemplateExportSession;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareRule;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTabResource;
 import org.gcube.portlets.user.td.gwtservice.shared.share.ShareTemplate;
 import org.gcube.portlets.user.td.gwtservice.shared.source.SDMXRegistrySource;
-import org.gcube.portlets.user.td.gwtservice.shared.statistical.StatisticalOperationSession;
+import org.gcube.portlets.user.td.gwtservice.shared.statistical.DataMinerOperationSession;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResubmitSession;
 import org.gcube.portlets.user.td.gwtservice.shared.task.TaskResumeSession;
 import org.gcube.portlets.user.td.gwtservice.shared.task.ValidationsTasksMetadata;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateApplySession;
+import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateColumnData;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateData;
 import org.gcube.portlets.user.td.gwtservice.shared.template.TemplateDeleteSession;
 import org.gcube.portlets.user.td.gwtservice.shared.tr.RefColumn;
@@ -115,7 +117,6 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public UserInfo hello() throws TDGWTServiceException;
 
-	
 	/**
 	 * Set locale on server
 	 * 
@@ -123,7 +124,7 @@ public interface TDGWTService extends RemoteService {
 	 * @throws TDGWTServiceException
 	 */
 	public void setLocale(InfoLocale infoLocale) throws TDGWTServiceException;
-	
+
 	/**
 	 * Retrieve pending Tasks and set them as background tasks
 	 * 
@@ -149,6 +150,14 @@ public interface TDGWTService extends RemoteService {
 	public String getUriFromResolver(UriResolverSession uriResolverSession)
 			throws TDGWTServiceException;
 
+	/**
+	 * Get VRE Folder Id
+	 * 
+	 * @return VRE Folder Id
+	 * @throws TDGWTServiceException
+	 */
+	public String getVREFolderIdByScope() throws TDGWTServiceException;
+
 	// PeriodDataType
 	/**
 	 * Get list of PeriodDataType
@@ -759,8 +768,6 @@ public interface TDGWTService extends RemoteService {
 	public AvailableCharsetList getAvailableCharsetForExport()
 			throws TDGWTServiceException;
 
-	
-	
 	/**
 	 * Start CSV Export and invokes the client library
 	 * 
@@ -782,6 +789,20 @@ public interface TDGWTService extends RemoteService {
 	public String startSDMXExport(SDMXExportSession exportSession)
 			throws TDGWTServiceException;
 
+	// Export Template SDMX
+	/**
+	 * 
+	 * Start SDMX Template Export and invokes the client library
+	 * 
+	 * @param sdmxTemplateExportSession
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public String startSDMXTemplateExport(
+			SDMXTemplateExportSession sdmxTemplateExportSession)
+			throws TDGWTServiceException;
+
+	
 	// Export JSON
 	/**
 	 * Start JSON Export and invokes the client library
@@ -989,6 +1010,30 @@ public interface TDGWTService extends RemoteService {
 	 */
 	public ArrayList<TemplateData> getTemplates() throws TDGWTServiceException;
 
+	/**
+	 * 
+	 * Retrieves templates for export as DSD in SDMX registry.
+	 * Template must have at least a measure column. 
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ArrayList<TemplateData> getTemplatesForDSDExport()
+			throws TDGWTServiceException;
+
+	
+	/**
+	 * 
+	 * Retrieves the columns of the specific template.
+	 * Template must have at least a measure column. 
+	 * 
+	 * @return
+	 * @throws TDGWTServiceException
+	 */
+	public ArrayList<TemplateColumnData> getTemplateColumnsData(String templateId)
+			throws TDGWTServiceException;
+
+	
 	/**
 	 * Start Apply Template
 	 * 
@@ -1223,15 +1268,15 @@ public interface TDGWTService extends RemoteService {
 	public String startMapCreation(MapCreationSession mapCreationSession)
 			throws TDGWTServiceException;
 
-	// Statistical
+	// DataMiner
 	/**
 	 * 
-	 * @param statisticalOperationSession
+	 * @param dataMinerOperationSession
 	 * @return
 	 * @throws TDGWTServiceException
 	 */
-	public String startStatisticalOperation(
-			StatisticalOperationSession statisticalOperationSession)
+	public String startDataMinerOperation(
+			DataMinerOperationSession dataMinerOperationSession)
 			throws TDGWTServiceException;
 
 	// Chart
@@ -1282,4 +1327,6 @@ public interface TDGWTService extends RemoteService {
 			GeometryCreatePointSession geometryCreatePointSession)
 			throws TDGWTServiceException;
 
+	
+
 }
